@@ -7,17 +7,25 @@ import os
 
 
 def ez(curr):
-    routes = {
-        'dev': os.path.dirname(__file__) + '{0}/dev.conf',
-        'test': os.path.dirname(__file__) + '{0}/test.conf',
-        'ol': os.path.dirname(__file__) + '{0}/online.conf',
-    }
 
-    bind_hosts(curr, routes)
+    # to specify routes
+    # routes = {
+    #     'dev': os.path.dirname(__file__) + '{0}/dev.conf',
+    #     'beta': os.path.dirname(__file__) + '{0}/beta.conf',
+    #     'ol': os.path.dirname(__file__) + '{0}/online.conf',
+    # }
+    #
+    # bind_hosts(curr, routes)
+
+    # create routes auto
+    bind_hosts(curr)
+
+    # use cloud feature
+    # bind_cloud(['pek2','app_key','app_secret'])
     pass
 
 
-def fabez_debug():
+def hello_fabric():
     local('echo "You can delete this function after initial it."')
     pass
 
@@ -30,8 +38,8 @@ def upgrade(tag=None, clean=False):
     :return:
     """
 
-    root = '/tmp/test.fabez.co'  # repo deploy path
-    repo = 'https://github.com/mybots/fabez-demo.git'  # repo demo
+    root = '/tmp/cabric'  # repo deploy path
+    repo = 'https://github.com/baixing/cabric.git'  # repo demo
 
     if clean:
         run('rm -rf %s' % root)
@@ -40,17 +48,22 @@ def upgrade(tag=None, clean=False):
     if ez_env.group == 'ol':
         cmd_git(root, repo, branch='master', tag=tag)
         pass
-    elif ez_env.group == 'test':
+    elif ez_env.group == 'beta':
         cmd_git(root, repo, branch='beta', tag=tag)
         pass
+    # you should create branch and dev.conf files
     elif ez_env.group == 'dev':
         cmd_git(root, repo, branch='dev', tag=tag)
         pass
     else:
-        print "找不到指定的配置环境,使用默认"
-        cmd_git(root, repo, branch='master', user='webuser', tag=tag)
+        print("[warn]:can't find default config,use master.")
+        cmd_git(root, repo, branch='master', tag=tag)
         pass
 
     pass
 
 
+
+
+
+
